import { XXH64 } from "xxh3-ts"

// Sometimes, the magnitude of the BigInt value generated by XXH64()
// is not large enough to require 16 characters when represented in base 16.
// As a result, the base 16 representation has leading zeros that are not necessary,
// and JavaScript omits them when converting the BigInt to a string. To fix this,
// we add zeros in the beginning until we reach a length of 16.

export function hashString(str: string): string {
  return XXH64(Buffer.from(str)).toString(16).padStart(16, "0")
}

export function hashObject(obj: object): string {
  return XXH64(Buffer.from(JSON.stringify(obj)))
    .toString(16)
    .padStart(16, "0")
}
